---
title: '결제대행사별 문의처 '
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제대행사 계약
seo:
  title: 결제대행사별 문의처
  description: PG사별 고객센터와 문의처의 정보를 안내해 드립니다. PG사로 직접 문의하고자 하실 경우 안내드리는 문의처를 참고하여 주시기 바랍니다.
  keywords:
    - PG사고객센터
tags:
  - 공통
  - 결제대행사 계약
pgCompanies:
  - 공통
searchTags:
  - 토스고객센터
  - 이니시스고객센터
  - 나이스페이고객센터
  - PG연락처
  - pg사연락처
  - pg사문의
  - 고객센터
  - pg사문의처
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="결제대행사별로 문의하실 수 있는 고객센터 연락처를 안내드립니다." title="" />

#### **NHN KCP**

- 유선문의처 : 1544-8667 (일반상담) , 1544-8662 (신규/제휴상담)
- 그 외 문의채널 : <help@kcp.co.kr>
- 홈페이지 : <https://www.kcp.co.kr/>

#### **KG이니시스(이니페이)**

- 유선문의처 : 02-3430-5858 - 1 (신규계약부서) , 1588-4954 (고객센터)
- 그 외 문의채널(메일) : <ch@kggroup.co.kr> 혹은 홈페이지 내 톡 문의 가능
- 홈페이지 : <https://www.inicis.com/>

#### **나이스페이먼츠(나이스페이)**

- 유선문의처 : 1661-7335 - 3 (신규 계약 부서)
- 그 외 문의채널(메일)
  - 계약부서 : <pghelp@nicepay.co.kr>
  - 기술지원 : <it@nicepay.co.kr>
- 홈페이지 : [https://www.nicepay.co.kr/](https://www.nicepay.co.kr/home/main.do)

#### **토스페이먼츠**

- 유선문의처 : 1544-7772 - 2 - 4 (계약 여부 및 심사 관련) , 1544-7772 - 2 - 5 (기술지원 및 결제 오류)
- 그 외 문의채널(메일) : <support@tosspayments.com>
- 홈페이지 : <https://www.tosspayments.com/>

#### **KSNET(KSPAY)**

- 유선문의처 : 1544-6030
- 홈페이지 : <https://www.ksnet.co.kr/>

#### **다날(다날페이)**

- 유선문의처 : 1566-3355 (고객센터) , 031-697-1280 (포트원(호스팅) 계약 담당부서)
- 그 외 문의채널(메일) : <portone.cs@danal.co.kr> (포트원(호스팅) 계약 담당부서)
- 홈페이지 : <https://www.danalpay.com/>

#### **헥토파이낸셜**

- 유선문의처 : 1600-5130 , 02-6092-5111
- 그 외 문의채널(메일) : <info_F@hecto.co.kr>
- 홈페이지 : <https://www.hectofinancial.co.kr/>

#### **키움페이**

- 유선문의처 : 1588-5984
- 그 외 문의채널(메일) : <help@kiwoompay.co.kr>
- 홈페이지 : <https://pg.kiwoompay.co.kr/>

#### **이지페이(KICC)**

- 유선문의처 : 1600-1234
- 홈페이지 : [ ](https://www.kcp.co.kr/main.do)<https://easypay.co.kr/>

#### **스마트로(스마트로페이)**

- 유선문의처 : 1666-9114
- 홈페이지 : <https://pg.smartro.co.kr/>

#### **블루월넛**

- 유선문의처 : 1522-4910
- 그 외 문의채널(메일) : <bluewalnut@bluewalnut.co.kr>
- 홈페이지 : <https://bluewalnut.co.kr/>

#### **카카오페이**

- 유선문의처 : 1644-7108(가맹점센터)
- 그 외 문의채널(메일) : <pg@kakaopaycorp.com>
- 홈페이지 : [https://biz.kakaopay.com/](https://biz.kakaopay.com/online/apply/hosting/1)

#### **네이버페이**

- 유선문의처 : 1588-3819 - 2 - 2 - 2
- 그 외 문의채널 : 1:1문의 \[[바로가기](https://help.admin.pay.naver.com/index.help)]
- 홈페이지 : <https://admin.pay.naver.com/>

#### **토스페이 간편결제**

- 유선문의처 : 1599-4905
- 그 외 문의채널(메일) : <support-pay@toss.im>
- 홈페이지 : <https://pay.toss.im/>

#### **페이코**

- 유선문의처 : 1544-8665
- 그 외 문의채널(메일) : <help-partner@payco.com>
- 홈페이지 : <https://www.payco.com/>

#### **스마일페이(LG CNS)**

- 유선문의처 : 1644-8455
- 그 외 문의채널(메일) : <cnspay@lgcns.com>
- 홈페이지 : [https://www.cnspay.co.kr/](https://www.cnspay.co.kr/intro/method_of_payment.dev?type=smilepay)

#### **엑심베이**

- 유선문의처 : 없음
- 그 외 문의채널(메일) : <onlinesupport@eximbay.com>
- 홈페이지 : <https://www.eximbay.com/index.do>

#### **페이먼트월**

- 유선문의처 : 없음
- 그 외 문의채널(메일) : <support@paymentwall.com>
- 홈페이지 : <https://www.paymentwall.com/kr/>

#### **KG모빌리언스**

- 유선문의처 : 1800-0678
- 그 외 문의채널(메일) : <mobilpay@kggroup.co.kr>
- 홈페이지 : [https://www.mobilians.co.kr/](https://www.mobilians.co.kr/mpay/sys/main/index.do)

#### **웰컴페이먼츠**

- 유선문의처 : 02-838-2001
- 그 외 문의채널(메일) : <master@welcomepayments.co.kr>
- 홈페이지 : <https://www.welcomepayments.co.kr/>

#### **한국결제네트웍스(KPN)**

- 유선문의처 : 02-1544-3850
- 그 외 문의채널 : 1:1 문의 \[[바로가기](https://www.kpn.co.kr/customer/ask.do)]
- 홈페이지 : <https://www.kpn.co.kr/main.do>
